pub enum CompoundCommand {
Arithmetic(ArithmeticCommand),
ArithmeticForClause(ArithmeticForClauseCommand),
BraceGroup(BraceGroupCommand),
Subshell(SubshellCommand),
ForClause(ForClauseCommand),
CaseClause(CaseClauseCommand),
IfClause(IfClauseCommand),
WhileClause(WhileOrUntilClauseCommand),
UntilClause(WhileOrUntilClauseCommand),
Coprocess(CoprocessCommand),
ExtendedTest(ExtendedTestExprCommand),
}Expand description
Represents a compound command, potentially made up of multiple nested commands.
Variants
Arithmetic(ArithmeticCommand)
An arithmetic command, evaluating an arithmetic expression.
ArithmeticForClause(ArithmeticForClauseCommand)
An arithmetic for clause, which loops until an arithmetic condition is reached.
BraceGroup(BraceGroupCommand)
A brace group, which groups commands together.
Subshell(SubshellCommand)
A subshell, which executes commands in a subshell.
ForClause(ForClauseCommand)
A for clause, which loops over a set of values.
CaseClause(CaseClauseCommand)
A case clause, which selects a command based on a value and a set of pattern-based filters.
IfClause(IfClauseCommand)
An if clause, which conditionally executes a command.
WhileClause(WhileOrUntilClauseCommand)
A while clause, which loops while a condition is met.
UntilClause(WhileOrUntilClauseCommand)
An until clause, which loops until a condition is met.
Coprocess(CoprocessCommand)
A coprocess, which runs a command asynchronously in a subshell.
ExtendedTest(ExtendedTestExprCommand)
An extended test command, evaluating an extended test expression.