pub struct IfClauseCommand {
pub condition: CompoundList,
pub then: CompoundList,
pub elses: Option<Vec<ElseClause>>,
pub loc: SourceSpan,
}Expand description
An if clause, which conditionally executes a command.
Fields
condition: CompoundListThe command whose execution result is inspected.
then: CompoundListThe command to execute if the condition is true.
elses: Option<Vec<ElseClause>>Optionally, else clauses that will be evaluated if the condition is false.
loc: SourceSpanLocation of the if clause