Parser for shell words, used in expansion and other contexts.
Implements support for:
- Text quoting (single, double, ANSI C).
- Escape sequences.
- Tilde prefixes.
- Parameter expansion expressions.
- Command substitution expressions.
- Arithmetic expansion expressions.
Structs
- Word
Piece With Source - Encapsulates a
WordPiecetogether with its position in the string it came from.
Enums
- Brace
Expression Member - Member of a brace expression.
- Brace
Expression OrText - Represents a sub-word that is either a brace expression or some other word text.
- Parameter
- A parameter, used in a parameter expansion.
- Parameter
Expr - A parameter expression, used in a parameter expansion.
- Parameter
Test Type - Type of a parameter test.
- Parameter
Transform Op - Kind of operation to apply to a parameter.
- Special
Parameter - A special parameter, used in a parameter expansion.
- Substring
Match Kind - Kind of substring match.
- Word
Piece - Represents a piece of a word.
Functions
- parse
- Parse a word into its constituent pieces.
- parse_
brace_ expansions - Parse brace expansion from a given word .
- parse_
parameter - Parse the given word into a parameter expression.
Type Aliases
- Brace
Expression - Represents a brace expression to be expanded.